@@ -70,7 +70,7 @@ impl<'a> ToGlibPtr<'a, *mut gobject_ffi::GParamSpec> for ParamSpecExpression {
 #[doc(hidden)]
 impl IntoGlibPtr<*mut gobject_ffi::GParamSpec> for ParamSpecExpression {
     #[inline]
-    unsafe fn into_glib_ptr(self) -> *mut gobject_ffi::GParamSpec {
+    fn into_glib_ptr(self) -> *mut gobject_ffi::GParamSpec {
         let s = std::mem::ManuallyDrop::new(self);
         s.to_glib_none().0
     }
@@ -79,7 +79,7 @@ impl IntoGlibPtr<*mut gobject_ffi::GParamSpec> for ParamSpecExpression {
 #[doc(hidden)]
 impl IntoGlibPtr<*const gobject_ffi::GParamSpec> for ParamSpecExpression {
     #[inline]
-    unsafe fn into_glib_ptr(self) -> *const gobject_ffi::GParamSpec {
+    fn into_glib_ptr(self) -> *const gobject_ffi::GParamSpec {
         let s = std::mem::ManuallyDrop::new(self);
         s.to_glib_none().0
     }
@@ -127,7 +127,7 @@ impl ParamSpecExpression {
     /// This method returns an instance of
     /// [`ParamSpecExpressionBuilder`](crate::builders::ParamSpecExpressionBuilder)
     /// which can be used to create [`ParamSpecExpression`] objects.
-    pub fn builder(name: &str) -> ParamSpecExpressionBuilder {
+    pub fn builder(name: &str) -> ParamSpecExpressionBuilder<'_> {
         assert_initialized_main_thread!();
         ParamSpecExpressionBuilder::new(name)
     }
